@@ -28,7 +28,7 @@ class ClusterRoleBinding(Resource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.cluster_role:
                 raise MissingRequiredArgumentError(argument="cluster_role")
 
